@@ -6,9 +6,14 @@
  * for more information.
  */
 
+/* This code was tested on a 9000/710 running HP-UX 9.05 with 8 kHz,
+ * 16 bit mono output.
+ */
+
 #include "config.h"
 
 #include <unistd.h>
+#include <stdlib.h>
 #include <string.h>
 #include <sys/ioctl.h>
 #include <sys/audio.h>
@@ -29,11 +34,15 @@ static void shutdown (void);
 
 static void dummy () { }
 
+/* Standard sampling rates */
+static int srate[] = {
+    44100, 32000, 22050, 16000, 11025, 8000, 0
+};
 
 static char *help[] = {
     "gain=val", "Audio output gain (0 to 255)",
     "port={s|h|l}", "Audio port (s[peaker], h[eadphones], l[ineout])",
-    "buffer=val", "Audio buffer size (default is 32768)",
+    "buffer=val", "Audio buffer size",
     NULL
 };
 
@@ -68,13 +77,14 @@ struct xmp_drv_info drv_hpux = {
 static int setaudio (struct drv_config *cfg)
 {
     int flags;
-    int gain = 128
+    int gain = 128;
     int bsize = 32 * 1024;
     int port = AUDIO_OUT_SPEAKER;
     struct audio_gains agains;
     struct audio_describe adescribe;
     char *token;
     char **parm = cfg->parm;
+    int i;
 
     parm_init ();
     chkparm1 ("gain", gain = strtoul (token, NULL, 0));
@@ -93,7 +103,7 @@ static int setaudio (struct drv_config *cfg)
         port = AUDIO_OUT_SPEAKER;
     }
 
-    flags = fcntl (audio_fd, F_GETFL, 0)) < 0);
+    flags = fcntl (audio_fd, F_GETFL, 0);
 
     if (flags < 0)
 	return 0;
@@ -104,26 +114,38 @@ static int setaudio (struct drv_config *cfg)
     if (flags < 0)
 	return 0;
 
-    if (ioctl (audio_fd, AUDIO_SET_DATA_FORMAT, AUDIO_FORMAT_LINEAR16BIT) == -1
-	|| ioctl (audio_fd, AUDIO_SET_CHANNELS, ++cfg.mode) == -1 
-	|| ioctl (audio_fd, AUDIO_SET_OUTPUT, port) == -1
-	|| ioctl (audio_fd, AUDIO_SET_SAMPLE_RATE, cfg->rate) == -1)
+    if (ioctl (audio_fd, AUDIO_SET_DATA_FORMAT, AUDIO_FORMAT_LINEAR16BIT) == -1)
 	return 0;
 
-    if (ioctl(audio_fd, AUDIO_DESCRIBE, &adescribe) == -1)
+    if (ioctl (audio_fd, AUDIO_SET_CHANNELS, cfg->mode + 1) == -1) {
+	cfg->mode = !cfg->mode;
+        if (ioctl (audio_fd, AUDIO_SET_CHANNELS, cfg->mode + 1) == -1)
+	    return 0;
+	cfg->mode++;
+    }
+
+    ioctl (audio_fd, AUDIO_SET_OUTPUT, port);
+
+    for (i = 0; ioctl (audio_fd, AUDIO_SET_SAMPLE_RATE, cfg->rate) == -1; i++) {
+	if ((cfg->rate = srate[i]) == 0)
+	    return 0;
+    }
+
+    if (ioctl (audio_fd, AUDIO_DESCRIBE, &adescribe) == -1)
 	return 0;
 
     if (ioctl (audio_fd, AUDIO_GET_GAINS, &agains) == -1)
 	return 0;
 
     agains.transmit_gain = adescribe.min_transmit_gain +
-	(description.max_transmit_gain - description.min_transmit_gain) *
+	(adescribe.max_transmit_gain - adescribe.min_transmit_gain) *
 	gain / 256;
 		
-    if (ioctl (audio_fd, AUDIO_SET_GAINS, &gains) == -1
-	|| ioctl(audio_fd, AUDIO_SET_TXBUFSIZE, bsize) == -1)
+    if (ioctl (audio_fd, AUDIO_SET_GAINS, &agains) == -1)
 	return 0;
 
+    ioctl(audio_fd, AUDIO_SET_TXBUFSIZE, bsize);
+
     return 1;
 }
 	
@@ -140,7 +162,8 @@ static int init (struct drv_config *cfg)
 
     cfg->fmt &= 0xffff;
 
-    setaudio (cfg);
+    if (!setaudio (cfg))
+	return 0;
 
     smix_init (cfg);
 
