@@ -1,5 +1,5 @@
-/* Extended Module Player - drivers/oss_seq.c
- * Copyright (C) 1997 Claudio Matsuoka and Hipolito Carraro Jr
+/* Extended Module Player
+ * Copyright (C) 1996-98 Claudio Matsuoka and Hipolito Carraro Jr
  * AWE32 support Copyright (C) 1996, 97 Takashi Iwai
  *
  * This file is part of the Extended Module Player and is distributed
@@ -21,10 +21,28 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
-#include <sys/soundcard.h>
 
-#include "ultrasound.h"
-#include "awe_voice.h"
+#if defined(HAVE_SYS_SOUNDCARD_H)
+#include <sys/soundcard.h>
+#elif defined(HAVE_MACHINE_SOUNDCARD_H)
+#include <machine/soundcard.h>
+#endif
+
+#if defined(HAVE_SYS_ULTRASOUND_H)
+#include <sys/ultrasound.h>
+#elif defined(HAVE_LINUX_ULTRASOUND_H)
+#include <linux/ultrasound.h>
+#elif defined(HAVE_MACHINE_ULTRASOUND_H)
+#include <machine/ultrasound.h>
+#endif
+
+#if defined(HAVE_AWE_VOICE_H)
+#include <awe_voice.h>
+#elif defined(HAVE_SYS_AWE_VOICE_H)
+#include <sys/awe_voice.h>
+#elif defined(HAVE_LINUX_AWE_VOICE_H)
+#include <linux/awe_voice.h>
+#endif
 
 #include "xmpi.h"
 #include "driver.h"
