@@ -30,16 +30,23 @@
 #define XMP_MOD_PAUSE	0x05
 #define XMP_GVOL_INC	0x06
 #define XMP_GVOL_DEC	0x07
+#define XMP_TIMER_STOP          0x08
+#define XMP_TIMER_RESTART       0x09
 
-#define xmp_ord_next()		xmp_player_ctl (XMP_ORD_NEXT)
-#define xmp_ord_prev()		xmp_player_ctl (XMP_ORD_PREV)
-#define xmp_mod_stop()		xmp_player_ctl (XMP_MOD_STOP)
-#define xmp_stop_module()	xmp_player_ctl (XMP_MOD_STOP)
-#define xmp_mod_restart()	xmp_player_ctl (XMP_MOD_RESTART)
-#define xmp_restart_module()	xmp_player_ctl (XMP_MOD_RESTART)
-#define xmp_mod_pause()		xmp_player_ctl (XMP_MOD_PAUSE)
-#define xmp_gvol_inc()		xmp_player_ctl (XMP_GVOL_INC)
-#define xmp_gvol_dec()		xmp_player_ctl (XMP_GVOL_DEC)
+#define xmp_ord_next()		xmp_player_ctl (XMP_ORD_NEXT, 0)
+#define xmp_ord_prev()		xmp_player_ctl (XMP_ORD_PREV, 0)
+#define xmp_ord_set(x)		xmp_player_ctl (XMP_ORD_PREV, (x))
+#define xmp_mod_stop()		xmp_player_ctl (XMP_MOD_STOP, 0)
+#define xmp_stop_module()	xmp_player_ctl (XMP_MOD_STOP, 0)
+#define xmp_mod_restart()	xmp_player_ctl (XMP_MOD_RESTART, 0)
+#define xmp_restart_module()	xmp_player_ctl (XMP_MOD_RESTART, 0)
+#define xmp_mod_pause()		xmp_player_ctl (XMP_MOD_PAUSE, 0)
+#define xmp_gvol_inc()		xmp_player_ctl (XMP_GVOL_INC, 0)
+#define xmp_gvol_dec()		xmp_player_ctl (XMP_GVOL_DEC, 0)
+#define xmp_timer_stop()        xmp_player_ctl (XMP_TIMER_STOP, 0)
+#define xmp_timer_restart()     xmp_player_ctl (XMP_TIMER_RESTART, 0)
+#define xmp_mod_load            xmp_load_module
+#define xmp_mod_play            xmp_play_module
 
 /* Errors */
 
@@ -152,7 +159,7 @@ void	xmp_set_driver_parameter 	(char *);
 void	xmp_channel_mute		(int, int, int);
 void	xmp_get_driver_cfg		(int *, int *, int *, int *);
 void	xmp_register_event_callback	(void (*)());
-int	xmp_player_ctl			(int);
+int	xmp_player_ctl			(int, int);
 
 int	xmp_tell_parent			(void);
 int	xmp_wait_parent			(void);
@@ -162,5 +169,6 @@ int	xmp_wait_child			(void);
 int	xmp_check_child			(int);
 void*	xmp_get_shared_mem		(int);
 void	xmp_detach_shared_mem		(void *);
+int	xmp_verbosity_level		(int);
 
 #endif /* __XMP_H */
