@@ -21,8 +21,10 @@ void xmpi_display_license ()
 	|| defined (HAVE_SYS_AWE_VOICE_H)
 "AWE-specific portions of oss_seq Copyright (C) 1996,1997 by Takashi Iwai.\n"
 #endif
-"ADPCM decoder Copyright (C) 1992 by Stichting Mathematisch Centrum, "
-"Amsterdam,\nThe Netherlands.\n"
+"ulaw encoder Copyright (C) 1989 by Rich Gopstein and Harris Corporation.\n"
+"ADPCM decoder Copyright (C) 1992 Stichting Mathematisch Centrum, Amsterdam,\n"
+"    The Netherlands.\n"
+
 "\nThis program is free software; you can redistribute it and/or modify it "
 "under\nthe terms of the GNU General Public License as published by the Free "
 "Software \nFoundation; either version 2, or (at your option) any later "
