@@ -52,6 +52,8 @@ struct channel_info {
 #define LIM_FT		12
 #define LIM8_HI		127
 #define LIM8_LO		-127
+#define LIM12_HI	4095
+#define LIM12_LO	-4096
 #define LIM16_HI	32767
 #define LIM16_LO	-32768
 
@@ -146,7 +148,7 @@ static void out_st8itpt (int count, char *in_bk, int cur_bk, register int itpt)
 
 
 /* Handler for 16 bit samples, interpolated stereo output */
-static void out_st16itpt (int count, int16 * in_bk, int cur_bk, register int itpt)
+static void out_st16itpt (int count, int16 *in_bk, int cur_bk, register int itpt)
 {
     int vl, vr;
     int smp_x1 = 0, smp_dt = 0;
@@ -186,7 +188,7 @@ static void out_st8norm (int count, char *in_bk, int cur_bk, register int itpt)
 
 
 /* Handler for 16 bit samples, non-interpolated stereo output */
-static void out_st16norm (int count, int16 * in_bk, int cur_bk, register int itpt)
+static void out_st16norm (int count, int16 *in_bk, int cur_bk, register int itpt)
 {
     int vl, vr;
     register int smp_in;
@@ -223,7 +225,7 @@ static void out_mn8itpt (int count, char *in_bk, int cur_bk, register int itpt)
 
 
 /* Handler for 16 bit samples, interpolated mono output */
-static void out_mn16itpt (int count, int16 * in_bk, int cur_bk, register int itpt)
+static void out_mn16itpt (int count, int16 *in_bk, int cur_bk, register int itpt)
 {
     int smp_x1 = 0, smp_dt = 0, vl;
     register int smp_in;
@@ -258,7 +260,7 @@ static void out_mn8norm (int count, char *in_bk, int cur_bk, register int itpt)
 
 
 /* Handler for 16 bit samples, non-interpolated mono output */
-static void out_mn16norm (int count, int16 * in_bk, int cur_bk, register int itpt)
+static void out_mn16norm (int count, int16 *in_bk, int cur_bk, register int itpt)
 {
     int vl;
     register int smp_in;
@@ -320,7 +322,7 @@ int smix_mixer ()
 	}
 
 	for (t_cnt = Ticksize; t_cnt;) {
-	    /* How many samples can we write before the loop break or
+	    /* How many samples we can write before the loop break or
 	     * sample end ... */
 	    p_cnt = 1 + (((long long) (ci->end - ci->pos) << SHIFT_FT) -
 		ci->itpt) / Itpt_inc;
@@ -368,7 +370,17 @@ int smix_mixer ()
     dest_bk = Out_array[Out_cur];
 
     i = Ticksize * Cfg->mode;
-    if (Cfg->fmt & MIX_16BIT)
+
+    if (Cfg->fmt & MIX_ULAW) {
+	for (; i; --i, ++orig_bk, ++(int8 *) dest_bk) {
+	    sample = (*orig_bk >> (LIM_FT + 4));
+	    if (sample > LIM12_HI)
+		sample = LIM12_HI;
+	    else if (sample < LIM12_LO)
+		sample = LIM12_LO;
+	    *(int8 *) dest_bk = ulaw_encode (sample);
+	}
+    } else if (Cfg->fmt & MIX_16BIT) {
 	for (; i; --i, ++orig_bk, ++(int16 *) dest_bk) {
 	    sample = (*orig_bk >> LIM_FT);
 	    if (sample > LIM16_HI)
@@ -376,6 +388,7 @@ int smix_mixer ()
 	    else if (sample < LIM16_LO)
 		sample = LIM16_LO;
 	    *(int16 *) dest_bk = sample + Out_mask;
+	}
     } else {
 	for (; i; --i, ++orig_bk, ++(int8 *) dest_bk) {
 	    sample = (*orig_bk >> (LIM_FT + 8));
@@ -439,7 +452,6 @@ void smix_init (struct drv_config *cfg)
     static buf_alloc = 0;
 
     Cfg = cfg;
-
     Out_mask = 0x0000;
     Out_cur = 0;
     Patch_info_array = calloc (sizeof (struct patch_info), 256);
@@ -551,13 +563,24 @@ void smix_setnote (int chn, int note)
 void smix_voicepos (int chn, int index)
 {
     struct channel_info *ci = &Channel_info_array[chn];
+    int lend;
 
-    if (ci->fidx & FLAG_16BIT)
+    lend = Patch_info_array[ci->smp]->mode & WAVE_LOOPING ?
+	Patch_info_array[ci->smp]->loop_end : ci->end;
+
+    if (ci->fidx & FLAG_16BIT) {
 	index >>= 1;
+	lend >>= 1;
+    }
 
-    if (index < ci->end) {
-	ci->pos = index;
+    if (index < lend) {
 	ci->itpt = 0;
+	ci->pos = index;
+	if (ci->fidx & FLAG_BACKWARD) {
+	    ci->fidx ^= ci->fxor;
+	    ci->end = lend;
+	    Itpt_inc *= -1;
+	}
     } else {
 	ci->vol = 0;
     }
